function []=CascadeForecastPlot(MedianYForecastAll,Data,Dates,Vars,VarLabels,Horizon,LengthOfPast,FirstForecastDate,season,SubPlots,GraphTitle)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% PURPOSE:  Plots a 'cascade' of rolling forecasts along with the actual data
%
% INPUT:	MedianYForecastAll
%           Data
%           Dates
%           Vars
%           Horizon
%           FirstForecastDate   '1999Q4'
%
% OUTPUT:	
%
% AUTHOR:	Mattias Villani, Research Department, Sveriges Riksbank and 
%                            Department of Statistics, Stockholm University.
%                            E-mail: mattias.villani@riksbank.se.
% 
% FIRST VERSION:  2005-02-03 
% THIS VERSION:   2007-09-09
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

[Nrows,Ncols]=ConstructOptimalSubplot(length(Vars));
NData=size(Data,1);
i=0;
NRolling=size(MedianYForecastAll,3);
FirstForecastPeriod=find(Dates==FirstForecastDate);
FigHandle=figure;
set(FigHandle,'name',GraphTitle);
k=0;
for Var=Vars
    i=i+1;
    switch SubPlots
        case 0 % One figure for each variable
            if i>1
                FigHandle=figure;
                set(FigHandle,'name',GraphTitle)
            end
        case 1 % 2-by-2 subplots
            k=k+1;
            if rem(i,4)==1 & i>1 % i=5,9,13,...
                FigHandle=figure;
                set(FigHandle,'name',GraphTitle);
                k=1;
            end
                subplot(2,2,k)
        case 2 % All variables in the same figure
            subplot(Nrows,Ncols,i)
        otherwise
    end

    DataLineHandle=plot(Dates(FirstForecastPeriod-LengthOfPast+1:end),Data(FirstForecastPeriod-LengthOfPast+1:end,Var),'k');
    set(DataLineHandle,'LineWidth',2)
    hold on
    Time1=FirstForecastDate;
    Time2=Time1+Horizon/season-(1/season);
    DataStand=FirstForecastPeriod-2;
    for t=1:NRolling
        DataStand=DataStand+1;
        ForecastLineHandle=plot(Time1-(1/season):(1/season):Time2,[Data(DataStand,Var);MedianYForecastAll(:,Var,t)],'r');
        set(ForecastLineHandle,'LineWidth',1)
        Time1=Time1+(1/season);
        Time2=Time2+(1/season);
    end
    title(VarLabels{Var})
    set(gca,'fontsize',8)
    box off
    grid on
    axis tight
end